@@ -10,13 +10,13 @@ use File::Temp;
 use Mojo::SQLite::Database;
 use Mojo::SQLite::Migrations;
 use Scalar::Util qw(blessed weaken);
-use SQL::Abstract;
+use SQL::Abstract::Pg;
 use URI;
 use URI::db;
 
-our $VERSION = '3.005';
+our $VERSION = '3.006';
 
-has abstract => sub { SQL::Abstract->new(name_sep => '.', quote_char => '"') };
+has abstract => sub { SQL::Abstract::Pg->new(name_sep => '.', quote_char => '"') };
 has 'auto_migrate';
 has database_class  => 'Mojo::SQLite::Database';
 has dsn             => sub { _url_from_file(shift->_tempfile)->dbi_dsn };
@@ -265,17 +265,6 @@ L<additional temporary files|https://www.sqlite.org/tempfiles.html> safely.
   my $tempfile = catfile $tempdir, 'test.db';
   my $sql = Mojo::SQLite->new->from_filename($tempfile);
 
-L<SQL::Abstract::Pg> can provide additional features to the L<SQL::Abstract>
-query methods in L<Mojo::SQLite::Database>. The C<on_conflict> and C<for>
-features are not applicable to SQLite queries.
-
-  use SQL::Abstract::Pg;
-  my $sql = Mojo::SQLite->new->abstract(SQL::Abstract::Pg->new(name_sep => '.', quote_char => '"'));
-  $sql->db->select(['some_table', ['other_table', foo_id => 'id']],
-    ['foo', [bar => 'baz'], \q{datetime('now') as dt}],
-    {foo => 'value'},
-    {order_by => 'foo', limit => 10, offset => 5, group_by => ['foo'], having => {baz => 'value'}});
-
 =head1 EXAMPLES
 
 This distribution also contains a well-structured example
@@ -306,13 +295,22 @@ L<Mojo::SQLite> implements the following attributes.
   $sql         = $sql->abstract(SQL::Abstract->new);
 
 L<SQL::Abstract> object used to generate CRUD queries for
-L<Mojo::SQLite::Database>, defaults to setting C<name_sep> to C<.> and
-C<quote_char> to C<">. L<SQL::Abstract::Pg> may be used to provide additional
-features.
+L<Mojo::SQLite::Database>, defaults to a L<SQL::Abstract::Pg> object with
+C<name_sep> set to C<.> and C<quote_char> set to C<">.
 
   # Generate WHERE clause and bind values
   my($stmt, @bind) = $sql->abstract->where({foo => 'bar', baz => 'yada'});
 
+L<SQL::Abstract::Pg> provides additional features to the L<SQL::Abstract>
+query methods in L<Mojo::SQLite::Database> such as C<-json> and
+C<limit>/C<offset>. The C<on_conflict> and C<for> features are not applicable
+to SQLite queries.
+
+  $sql->db->select(['some_table', ['other_table', foo_id => 'id']],
+    ['foo', [bar => 'baz'], \q{datetime('now') as dt}],
+    {foo => 'value'},
+    {order_by => 'foo', limit => 10, offset => 5, group_by => ['foo'], having => {baz => 'value'}});
+
 =head2 auto_migrate
 
   my $bool = $sql->auto_migrate;
